@@ -40,6 +40,8 @@ CREATE TABLE chan (
   mode_us enum('Y','N') NOT NULL default 'N',
   mode_ut enum('Y','N') NOT NULL default 'N',
   mode_uv enum('Y','N') NOT NULL default 'N',
+  mode_ux enum('Y','N') NOT NULL default 'N',
+  mode_uu enum('Y','N') NOT NULL default 'N',
   mode_lf_data varchar(20) NOT NULL default '',
   mode_lj_data varchar(5) NOT NULL default '',
   mode_lk_data varchar(23) NOT NULL default '',
@@ -91,6 +93,7 @@ CREATE TABLE user (
   online enum('Y','N') NOT NULL DEFAULT 'Y',
   lastquit datetime default NULL,
   mode_la enum('Y','N') NOT NULL default 'N',
+  mode_lc enum('Y','N') NOT NULL default 'N',
   mode_ld enum('Y','N') NOT NULL default 'N',
   mode_lg enum('Y','N') NOT NULL default 'N',
   mode_lh enum('Y','N') NOT NULL default 'N',
@@ -115,6 +118,7 @@ CREATE TABLE user (
   mode_us enum('Y','N') NOT NULL default 'N',
   mode_ut enum('Y','N') NOT NULL default 'N',
   mode_uv enum('Y','N') NOT NULL default 'N',
+  mode_uu enum('Y','N') NOT NULL default 'N',
   mode_uw enum('Y','N') NOT NULL default 'N',
   PRIMARY KEY  (nickid),
   UNIQUE KEY nick (nick),
