@@ -70,8 +70,8 @@ void do_tburst(char *chan, char *time, char *author, char *topic);
 #define USERMODES "abcdefghiknorswyAR"
 #define CHANMODES "beIBXEovciklmnw7prstLMRO"
 #elif defined(IRCD_UNREAL)
-#define USERMODES "adghiopqrtvwxzABCDGHNRSTVW"
-#define CHANMODES "beIovahqcfijklmnprstuyzACDGHKLMNOQRSTV" /* ChanModes +I and +H are not used anymore in 3.2 beta19 */
+#define USERMODES "acdghiopqrtvwxzABCDGHNRSTUVW"
+#define CHANMODES "bceIovahqcfijklmnprstuyzACDGHKLMNOQRSTUV"
 #elif defined(IRCD_ULTIMATE)
 #define USERMODES "acdefghijkmnoprstwxyACDFJOPSTWZ"
 #define CHANMODES "beIovahceiklmnprstKNOR"
